@@ -1,5 +1,5 @@
 // Copyright Contributors to the OpenVDB Project
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: Apache-2.0
 
 #ifndef OPENVDB_MATH_QUAT_H_HAS_BEEN_INCLUDED
 #define OPENVDB_MATH_QUAT_H_HAS_BEEN_INCLUDED
@@ -9,6 +9,7 @@
 #include "Math.h"
 #include "Vec3.h"
 #include <openvdb/Exceptions.h>
+#include <openvdb/util/Assert.h>
 #include <cmath>
 #include <iostream>
 #include <sstream>
@@ -83,34 +84,9 @@ public:
     static const int size = 4;
 
     /// Trivial constructor, the quaternion is NOT initialized
-#if OPENVDB_ABI_VERSION_NUMBER >= 8
     /// @note destructor, copy constructor, assignment operator and
     ///   move constructor are left to be defined by the compiler (default)
     Quat() = default;
-#else
-    Quat() {}
-
-    /// Copy constructor
-    Quat(const Quat &q)
-    {
-        mm[0] = q.mm[0];
-        mm[1] = q.mm[1];
-        mm[2] = q.mm[2];
-        mm[3] = q.mm[3];
-
-    }
-
-    /// Assignment operator
-    Quat& operator=(const Quat &q)
-    {
-        mm[0] = q.mm[0];
-        mm[1] = q.mm[1];
-        mm[2] = q.mm[2];
-        mm[3] = q.mm[3];
-
-        return *this;
-    }
-#endif
 
     /// Constructor with four arguments, e.g.   Quatf q(1,2,3,4);
     Quat(T x, T y, T z, T w)
@@ -136,7 +112,7 @@ public:
     /// unit vector
     Quat(const Vec3<T> &axis, T angle)
     {
-        // assert( REL_EQ(axis.length(), 1.) );
+        OPENVDB_ASSERT(isApproxEqual(axis.length(), T(1)));
 
         T s = T(sin(angle*T(0.5)));
 
@@ -625,10 +601,8 @@ Mat3<T> bezLerp(const Mat3<T0> &m1, const Mat3<T0> &m2,
 using Quats = Quat<float>;
 using Quatd = Quat<double>;
 
-#if OPENVDB_ABI_VERSION_NUMBER >= 8
 OPENVDB_IS_POD(Quats)
 OPENVDB_IS_POD(Quatd)
-#endif
 
 } // namespace math
 
